%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Script that demonstrates numerical equivalence of Fresnel reflection
% coefficients for Stratton 1941 (complex wavenumber form) and Peters et al
% 2005 (complex permittivity form). The interface between glacier ice and
% saltwater is used as an example following dielectric material parameters
% in Table 1 of Peters et al. 2005
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% 1. general parameters
omega=50e6*2*pi; % angular radar frequency (assume 50 MHz for linear radar frequency)
epsilon_0=8.85e-12; % permittivity of free space (to convert loss tangent to conductivity)

% 2. Material parameters for salt water (based on table 1 in Peters et al.
% 2005)
eps_r_SW=77; % relative complex permittivity
loss_tangent_SW=11.4; % loss tangent
sigma_SW=loss_tangent_SW*omega*eps_r_SW*epsilon_0; % conductivity from loss tangent
eps_SW=eps_r_SW*(1-sqrt(-1)*loss_tangent_SW); % complex permittivity

% 3. Material paramters for glacier ice (based on table 1 in Peters et al.
% 2005)
eps_r_ice = 3.17; % relative permittivity 
loss_tangent_ice = 0.0062; % loss tangent
sigma_ice=loss_tangent_ice*omega*eps_r_ice*epsilon_0; %conductivity from loss tangent
eps_ice=eps_r_ice*(1-sqrt(-1)*loss_tangent_ice);  % relative complex permittivity

% 4. reflectivity for Peters 2005 formula
r=(sqrt(eps_ice)-sqrt(eps_SW))./(sqrt(eps_ice)+sqrt(eps_SW)); % e-field form
R=r.*conj(r); % intensity form
R_dB=10*log10(R); % log-dB form

% 5. reflectivty for Stratton 1941 formula
alpha_ice=omega*(0.5*eps_r_ice*epsilon_0*(sqrt(1+sigma_ice^2/(eps_r_ice*omega*epsilon_0)^2)+1))^0.5;
beta_ice=omega*(0.5*eps_r_ice*epsilon_0*(sqrt(1+sigma_ice^2/(eps_r_ice*omega*epsilon_0)^2)-1))^0.5;
k_ice=alpha_ice+sqrt(-1)*beta_ice; % complex k-vector in ice

alpha_SW=omega*(0.5*eps_r_SW*epsilon_0*(sqrt(1+sigma_SW^2/(eps_r_SW*omega*epsilon_0)^2)+1))^0.5;
beta_SW=omega*(0.5*eps_r_SW*epsilon_0*(sqrt(1+sigma_SW^2/(eps_r_SW*omega*epsilon_0)^2)-1))^0.5;
k_SW=alpha_SW+sqrt(-1)*beta_SW; % complex k-vector in salt water

rho=(k_ice-k_SW)./(k_ice+k_SW);% e-field form
RHO=rho.*conj(rho); % intensity form
RHO_dB=10*log10(RHO); % log-dB form

% running script will show R=RHO, R_dB=RHO_dB
